%global srcname pytest
%global pylib_version 1.4.33
%global sum Simple powerful testing with Python
%global pkgdesc \
py.test provides simple, yet powerful testing for Python.

Name:           python3-pytest
Version:        3.2.3
Release:        1%{?dist}
Summary:        %{sum}

License:        MIT
URL:            http://pytest.org
Source0:        https://github.com/pytest-dev/pytest/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# No sphinx.ext.viewcode, objname arg on EL6
Patch0:         python3-pytest-sphinx0.6.patch

BuildArch:      noarch
BuildRequires:  python-sphinx
# For sphinx
BuildRequires:  python-py
BuildRequires:  python-docutils
BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-setuptools
BuildRequires:  python%{python3_pkgversion}-py >= %{pylib_version}
%if 0%{?with_python3_other}
BuildRequires:  python%{python3_other_pkgversion}-devel
BuildRequires:  python%{python3_other_pkgversion}-setuptools
BuildRequires:  python%{python3_other_pkgversion}-py >= %{pylib_version}
%endif

# used by the testsuite, if present:
# if pexpect is present, the testsuite fails on F19 due to
# http://bugs.python.org/issue17998
#BuildRequires:  python%{python3_pkgversion}-pexpect
BuildRequires:  python%{python3_pkgversion}-mock
BuildRequires:  python%{python3_pkgversion}-hypothesis
%if 0%{?with_python3_other}
BuildRequires:  python%{python3_other_pkgversion}-mock
BuildRequires:  python%{python3_other_pkgversion}-hypothesis
%endif


%description %{pkgdesc}


%package -n python%{python3_pkgversion}-pytest
Summary:        %{sum}
Requires:       python%{python3_pkgversion}-setuptools
Requires:       python%{python3_pkgversion}-py >= %{pylib_version}

%description -n python%{python3_pkgversion}-pytest %{pkgdesc}

%if 0%{?with_python3_other}
%package -n python%{python3_other_pkgversion}-pytest
Summary:        %{sum}
Requires:       python%{python3_other_pkgversion}-setuptools
Requires:       python%{python3_other_pkgversion}-py >= %{pylib_version}

%description -n python%{python3_other_pkgversion}-pytest %{pkgdesc}
%endif


%prep
%setup -q -n %{srcname}-%{version}
%if 0%{?rhel} && 0%{?rhel} <= 6
%patch0 -p1 -b .sphinx0.6
sed -i -e '/include:: links.txt/d' doc/en/test/plugin/*.rst
%endif
# Help setuptools_scm find the version
[ -f PKG-INFO ] || echo "Version: %{version}" > PKG-INFO


%build
%{py3_build}
for l in doc/* ; do
  make -C $l html PYTHONPATH=$(pwd) %{?el6:|| :}
done
%if 0%{?with_python3_other}
%{py3_other_build}
%endif


%install
BINARIES="pytest py.test"

%if 0%{?with_python3_other}
%{py3_other_install}
# remove shebangs from all scripts
find %{buildroot}%{python3_other_sitelib} -name '*.py' \
     -exec sed -i -e '1{/^#!/d}' {} \;
for bin in $BINARIES; do
    mv %{buildroot}%{_bindir}/$bin{,-%{python3_other_version}}
done
%endif

%{py3_install}
for bin in $BINARIES; do
    mv %{buildroot}%{_bindir}/$bin{,-%{python3_version}}
    ln -snf $bin-%{python3_version} %{buildroot}%{_bindir}/$bin-3
done

# remove shebangs from all scripts
find %{buildroot}%{python3_sitelib} -name '*.py' \
     -exec sed -i -e '1{/^#!/d}' {} \;

mkdir -p _htmldocs/html
for l in doc/* ; do
  # remove hidden file
  rm -f ${l}/_build/html/.buildinfo
  mv ${l}/_build/html _htmldocs/html/${l##doc/}
done

rst2html README.rst > README.html


%check
PATH=%{buildroot}%{_bindir}:${PATH} \
PYTHONPATH=%{buildroot}%{python3_sitelib} \
  %{buildroot}%{_bindir}/py.test-%{python3_version} -r s testing
%if 0%{?with_python3_other}
PYTHONPATH=%{buildroot}%{python3_other_sitelib} \
  %{buildroot}%{_bindir}/py.test-%{python3_other_version} -r s testing
%endif


%files -n python%{python3_pkgversion}-pytest
%doc CHANGELOG.rst
%doc README.html
%doc _htmldocs/html
%license LICENSE
%{_bindir}/py.test-3
%{_bindir}/py.test-%{python3_version}
%{_bindir}/pytest-3
%{_bindir}/pytest-%{python3_version}
%{python3_sitelib}/*

%if 0%{?with_python3_other}
%files -n python%{python3_other_pkgversion}-pytest
%doc CHANGELOG.rst
%doc README.html
%doc _htmldocs/html
%license LICENSE
%{_bindir}/py.test-%{python3_other_version}
%{_bindir}/pytest-%{python3_other_version}
%{python3_other_sitelib}/*
%endif


%changelog
* Fri Oct 06 2017 Aurelien Bompard <abompard@fedoraproject.org> - 3.2.3-1
- Build for python3_other
- Update to 3.2.3 because 2.x was not compatible with Python 3.6

* Wed Nov 2 2016 Orion Poplawski <orion@cora.nwra.com> - 2.8.5-3
- Do as much as we can to build docs on EL6

* Wed Dec 30 2015 Orion Poplawski <orion@cora.nwra.com> - 2.8.5-2
- Use github tarball for source

* Wed Dec 30 2015 Orion Poplawski <orion@cora.nwra.com> - 2.8.5-1
- Intiial EPEL package
